<?php

defined('BASEPATH') or exit('No direct script access allowed');

class Center extends Home_Controller
{

    public function __construct()
    {
        parent::__construct();
        if (!$this->user->groupid) {
            header('Location: /login.html');
            exit;
        }

        $doc_count = $this->db->select('count(*) as count')->get_where('doc', array('userid' => $this->user->userid, 'state' => 1, 'isdel' => 0))->row();
        $view_count = $this->db->select('sum(readcount) as readcount')->get_where('doc', array('userid' => $this->user->userid, 'state' => 1, 'isdel' => 0))->row();
        $down_count = $this->db->select('sum(downcount) as downcount')->get_where('doc', array('userid' => $this->user->userid, 'state' => 1, 'isdel' => 0))->row();

        $yestoday = $this->db->select('sum(glods) as yesglods')->where_in('type', array(11, 12, 30, 31, 32, 40, 41, 42, 50, 51, 52))->get_where('glodpot', array('userid' => $this->user->userid, 'date(insertdate)' => date("Y-m-d", strtotime("-1 day"))))->row();

        $this->load->vars('doc_count', $doc_count->count);
        $this->load->vars('view_count', $view_count->readcount ? $view_count->readcount : 0);
        $this->load->vars('down_count', $down_count->downcount ? $down_count->downcount : 0);
        $this->load->vars('yestoday', $yestoday->yesglods ? round($yestoday->yesglods, 2) : 0);
    }

    public function index()
    {
        if (IS_GET) {
            $data['title'] = '我的文档 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的文档 - 我的后台';
            $data['description'] = '我的文档 - 我的后台';

            $this->load->view($this->template . 'center/index', $data);
        } else {
            $cpage = $this->input->post('pagecurrent');
            $pagesize = $this->input->post('pagesize');

            $mydoc = get_docs_bypage($this->user->userid, null, null, null, null, null, null, null, 1, $pagesize, $cpage, 'docid desc');
            foreach ($mydoc['data'] as $doc) {
                switch ($doc->state) {
                    case 0:
                        $doc->state = '<span style="color:#196">待审</span>';
                        break;
                    case 1:
                        $doc->state = '<span style="color:#f60">通过</span>';
                        break;
                    case -1:
                        $doc->state = '<span style="color:#f00">失败</span>';
                        break;
                    default:
                        $doc->state = '';
                }
                $doc->typename = $doc->typename ? $doc->typename : '<span style="color:#f00">分类已删</span>';
                $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
                $doc->downpay = $doc->downpay == null ? '<span class="tip-bg bg-red">禁止下载</span>' : ($doc->downpay == 0 ? '<span class="tip-bg bg-pink">免费</span>' : $doc->downpay.' '.$this->tradeset->glodunit);
                $doc->info = $doc->isimp ? '<span class="tip-bg bg-blue">推荐</span>' : '';
                $doc->info .= $doc->isvip ? ' <span class="tip-bg bg-red">VIP</span>' : '';
                $doc->info .= $doc->isdel ? ' <span class="tip-bg bg-green">下架</span>' : '';
            }
            echo json_encode($mydoc);
        }
    }

    public function menu()
    {
        $data['title'] = '我的中心 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的中心 - 我的后台';
        $data['description'] = '我的中心 - 我的后台';

        $this->load->view($this->template . 'center/menu', $data);
    }

    public function doc_del($docid)
    {
        if (!$this->has_right(15)) {
            echo -1; //没有删除权限
            return;
        }
        if ($docid && $doc = get_doc($docid)) {
            if ($this->user->userid == $doc->userid) {
                if ($doc->path) {
                    $this->db->delete('doc', array('docid' => $docid));
                    delfile($doc->path);
                    echo 1;
                }
            } else {
                echo -1; //只能删除自己的文档
            }
        }
    }
    public function income()
    {
        $data['title'] = '我的收入 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的收入 - 我的后台';
        $data['description'] = '我的收入 - 我的后台';

        $this->load->view($this->template . 'center/income', $data);
    }

    public function income_doc()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(30, 31, 32, 40, 41, 42))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_doc_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            if ($doc->type == 30 || $doc->type == 31 || $doc->type == 32) {
                $doc->type = '文档阅读';
            }
            if ($doc->type == 40 || $doc->type == 41 || $doc->type == 42) {
                $doc->type = '文档下载';
            }
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function income_topic()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(50, 51, 52))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_topic_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            $doc->type = '专题下载';
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function income_reward()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(21))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_reward_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            $doc->type = '悬赏';
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function income_invite()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid))->where_in('type', [11, 12])->order_by('insertdate desc');

        $total = $this->db->count_all_results('glod_invite_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $invites = $this->db->get()->result();
        foreach ($invites as $invite) {
            if ($invite->type == 11) {
                $invite->type = "注册奖励";
                $invite->invite = $invite->invite . ' ' . $this->tradeset->glodunit;
                $invite->glods = $invite->glods . ' ' . $this->tradeset->glodunit;
            }
            if ($invite->type == 12) {
                $invite->type = "分红奖励";
                $invite->invite = $invite->invite;
                $invite->glods = ((int) $invite->glods * 100 / (float) $invite->invite) . '*' . $invite->invite . '=' . $invite->glods . ' ' . $this->tradeset->glodunit;
            }
            $invite->insertdate = date('Y-m-d', strtotime($invite->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $invites));
    }

    public function purchase()
    {
        $data['title'] = '我的支出 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的支出 - 我的后台';
        $data['description'] = '我的支出 - 我的后台';

        $this->load->view($this->template . 'center/purchase', $data);
    }

    public function purchase_doc()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(-30, -31, -32, -40, -41, -42))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_doc_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            if ($doc->type == -30 || $doc->type == -31 || $doc->type == -32) {
                $doc->type = '文档阅读';
            }
            if ($doc->type == -40 || $doc->type == -41 || $doc->type == -42) {
                $doc->type = '文档下载';
            }
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function purchase_topic()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(-50, -51, -52))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_topic_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            $doc->type = '专题下载';
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function purchase_reward()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->where_in('type', array(-21))->order_by('insertdate desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('glod_reward_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            $doc->type = '悬赏奖励';
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function down()
    {
        $data['title'] = '我的下载 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的下载 - 我的后台';
        $data['description'] = '我的下载 - 我的后台';

        $this->load->view($this->template . 'center/down', $data);
    }

    public function docdown()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->order_by('logid desc'); //title 为 null 说明下载的文档被删除

        $total = $this->db->count_all_results('downlog_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function topicdown()
    {

        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->order_by('logid desc'); //title 为 null 说明下载的文档被删除

        $total = $this->db->count_all_results('topic_downlog_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function favorite()
    {
        $data['title'] = '我的收藏 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的收藏 - 我的后台';
        $data['description'] = '我的收藏 - 我的后台';

        $this->load->view($this->template . 'center/favorite', $data);
    }

    public function docfavorite()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->order_by('favid desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('favorite_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function topicfavorite()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->order_by('favid desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('topic_favorite_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function rewardfavorite()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid, 'title<>' => null))->order_by('favid desc'); //title 为 null 说明收藏的文档被删除

        $total = $this->db->count_all_results('reward_favorite_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $docs = $this->db->get()->result();
        foreach ($docs as $doc) {
            $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $docs));
    }

    public function topic()
    {
        if (IS_GET) {
            $data['title'] = '我的专题 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的专题 - 我的后台';
            $data['description'] = '我的专题 - 我的后台';

            $this->load->view($this->template . 'center/topic', $data);
        } else {
            $cpage = $this->input->post('pagecurrent');
            $pagesize = $this->input->post('pagesize');

            $this->db->where(array('userid' => $this->user->userid))->order_by('topicid desc');

            $total = $this->db->count_all_results('topic_view', false);

            if ($pagesize && $cpage) {
                $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
            }

            $topics = $this->db->get()->result();
            foreach ($topics as $topic) {
                switch ($topic->state) {
                    case 0:
                        $topic->state = '<span style="color:#196">未审</span>';
                        break;
                    case 1:
                        $topic->state = '<span style="color:#f60">通过</span>';
                        break;
                    case -1:
                        $topic->state = '<span style="color:#f00">失败</span>';
                        break;
                    default:
                        $topic->state = '';
                }

                $row = $this->db->select('count(docid) as docnum,sum(downpay) as totalpay')->where_in('docid', explode(',', $topic->docs))->get('doc')->row();
                $topic->docnum = $row->docnum;
                $topic->totalpay = number_format($row->totalpay, 2, '.', '');
                $topic->downpay = number_format($topic->downpay == "" ? ($topic->discount == "" ? $topic->totalpay : $topic->discount * $topic->totalpay) : $topic->downpay, 2, '.', '');

                $topic->typename = $topic->typename ? $topic->typename : '<span style="color:#f00">分类已删</span>';
                $topic->downpay = $topic->downpay == '0.00' ? '<span class="tip-bg bg-pink">免费</span>' : $topic->downpay . $this->tradeset->glodunit;
                $topic->info = $topic->isdel ? ' <span class="tip-bg bg-green">下架</span>' : '';
                $topic->insertdate = date('Y-m-d', strtotime($topic->insertdate));
            }
            echo json_encode(array('total' => $total, 'data' => $topics));
        }
    }

    public function topic_del($topicid)
    {
        if ($this->has_right(45)) {
            $this->db->set('isdel', '1', false)->where(['topicid' => $topicid, 'userid' => $this->user->userid])->update('topic');
            echo 1;            
        } else {
            echo -1;
        }
    }

    public function reward()
    {
        $data['title'] = '我的悬赏 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的悬赏 - 我的后台';
        $data['description'] = '我的悬赏 - 我的后台';

        $this->load->view($this->template . 'center/reward', $data);
    }

    public function reward_pub()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid))->order_by('reid desc');

        $total = $this->db->count_all_results('reward_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $rewards = $this->db->get()->result();

        foreach ($rewards as $reward) {
            $reward->istop = $reward->istop ? '<span class="block">置顶</span>' : '';
            $reward->draftnum = $this->db->select('count(*) as count')->get_where('draft', array('state >=' => 0, 'reid' => $reward->reid))->row()->count;
            $reward->pubdate = date('Y-m-d', strtotime($reward->insertdate));
            switch ($reward->state) {
                case '0':
                    $reward->sshow = '<span style="color:#196">未审核</span>';
                    $reward->go = '查看';
                    break;
                case '1':
                    $reward->sshow = '<span style="color:#f60">未定稿</span>';
                    $reward->go = '定稿';
                    break;
                case '2':
                    $reward->sshow = '<span style="color:#f60">已定稿</span>';
                    $reward->go = '查看';
                    break;
                case '3':
                    $reward->sshow = '<span style="color:#f00">悬赏失败</span>';
                    $reward->go = '查看';
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $rewards));
    }

    public function reward_draft()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid))->order_by('draftid desc');

        $total = $this->db->count_all_results('draft_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $drafts = $this->db->get()->result();

        foreach ($drafts as $draft) {
            $draft->insertdate = date('Y-m-d', strtotime($draft->insertdate));
            switch ($draft->state) {
                case '0':
                    $draft->state = '<span style="color:#196">待审稿</span>';
                    break;
                case '1':
                    $draft->state = '<span style="color:#f60">中标</span>';
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $drafts));
    }

    public function reward_del($reid)
    {
        if (!$this->has_right(55)) {
            echo -1; //没有删除权限
            return;
        }

        if ($reid && $reward = $this->db->get_where('reward', array('state' => 0, 'reid' => $reid))->row()) {
            if ($this->user->userid == $reward->userid) {
                $this->db->delete('reward', array('reid' => $reid));
                echo 1;
            } else {
                echo -1; //只能删除自己的未审核的悬赏
            }
        } else {
            echo -1; //定稿了不能删
        }
    }

    public function draft_del($draftid)
    {
        if (!$this->has_right(59)) {
            echo -1; //没有删除权限
            return;
        }

        if ($draftid && $draft = $this->db->get_where('draft', array('state' => 0, 'draftid' => $draftid))->row()) {
            if ($this->user->userid == $draft->userid) {
                $this->db->delete('draft', array('draftid' => $draftid));
                echo 1;
            } else {
                echo -1; //只能删除自己的未审核的悬赏
            }
        } else {
            echo -1; //定稿了不能删
        }
    }

    public function ask()
    {
        if (IS_GET) {
            $data['title'] = '我的问题 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的问题 - 我的后台';
            $data['description'] = '我的问题 - 我的后台';

            $this->load->view($this->template . 'center/ask', $data);
        } else {
            $cpage = $this->input->post('pagecurrent');
            $pagesize = $this->input->post('pagesize');

            $this->db->where(array('userid' => $this->user->userid))->order_by('askid desc');

            $total = $this->db->count_all_results('ask_view', false);

            if ($pagesize && $cpage) {
                $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
            }

            $asks = $this->db->get()->result();

            foreach ($asks as $ask) {
                $ask->tagname = $ask->tagname ? $ask->tagname : '<span style="color:#f00">无分类</span>';
                $ask->istop = $ask->istop ? '<span class="block">置顶</span>' : '';
                $ask->commentnum = $this->db->select('count(*) as count')->get_where('ask_comment', array('state' => 1, 'askid' => $ask->askid))->row()->count;
                $ask->pubdate = date('Y-m-d', strtotime($ask->insertdate));
                switch ($ask->state) {
                    case '0':
                        $ask->state = '<span style="color:#196">未审核</span>';
                        break;
                    case '1':
                        $ask->state = '<span style="color:#f60">已审核</span>';
                        break;
                    case '-1':
                        $ask->state = '<span style="color:#f00">已删除</span>';
                        break;
                }
            }
            echo json_encode(array('total' => $total, 'data' => $asks));

        }
    }

    public function ask_reply()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid))->order_by('userid desc');

        $total = $this->db->count_all_results('ask_comment_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $comments = $this->db->get()->result();
        foreach ($comments as $comment) {
            $comment->pubdate = date('Y-m-d', strtotime($comment->insertdate));
            switch ($comment->state) {
                case 0:
                    $comment->state = '<span style="color:#196">未审核</span>';
                    break;
                case 1:
                    $comment->state = '<span style="color:#f60">已审核</span>';
                    break;
                default:
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $comments));
    }

    public function article()
    {
        if (IS_GET) {
            $data['title'] = '我的文章 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的文章 - 我的后台';
            $data['description'] = '我的文章 - 我的后台';

            $this->load->view($this->template . 'center/article', $data);
        } else {
            $cpage = $this->input->post('pagecurrent');
            $pagesize = $this->input->post('pagesize');

            $this->db->where(array('userid' => $this->user->userid))->order_by('articleid desc');

            $total = $this->db->count_all_results('article_view', false);

            if ($pagesize && $cpage) {
                $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
            }

            $articles = $this->db->get()->result();

            foreach ($articles as $article) {
                $article->tagname = $article->tagname ? $article->tagname : '<span style="color:#f00">无标签</span>';
                $article->istop = $article->istop ? '<span class="block">置顶</span>' : '';
                $article->commentnum = $this->db->select('count(*) as count')->get_where('article_comment', array('state' => 1, 'articleid' => $article->articleid))->row()->count;
                $article->pubdate = date('Y-m-d', strtotime($article->insertdate));
                switch ($article->state) {
                    case '0':
                        $article->state = '<span style="color:#196">未审核</span>';
                        break;
                    case '1':
                        $article->state = '<span style="color:#f60">已审核</span>';
                        break;
                    case '-1':
                        $article->state = '<span style="color:#f00">已删除</span>';
                        break;
                }
            }
            echo json_encode(array('total' => $total, 'data' => $articles));

        }
    }

    public function article_reply()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid))->order_by('userid desc');

        $total = $this->db->count_all_results('article_comment_view', false);

        if ($pagesize && $cpage) {
            $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
        }

        $comments = $this->db->get()->result();
        foreach ($comments as $comment) {
            $comment->pubdate = date('Y-m-d', strtotime($comment->insertdate));
            switch ($comment->state) {
                case 0:
                    $comment->state = '<span style="color:#196">未审核</span>';
                    break;
                case 1:
                    $comment->state = '<span style="color:#f60">已审核</span>';
                    break;
                default:
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $comments));
    }

    public function task()
    {
        $points = $this->db->get_where('points', array('state' => 1))->result();
        foreach ($points as $point) {
            switch ($point->id) {
                case 1:
                    break;
                case 2:
                    $data['login'] = $point->points;
                    break;
                case 3:
                    $data['info_points'] = $point->points;
                    $info = $this->db->get_where('pointpot', array('userid' => $this->user->userid, 'type' => 3))->row();
                    $data['info'] = $info;
                    break;
                case 4:
                    $upload = $this->db->order_by('id desc')->limit(5)->get_where('point_view', array('userid' => $this->user->userid, 'type' => 4))->result();
                    $data['upload'] = $upload;
                    break;
                case 5:
                    break;
                case 6:
                    break;
                case 7:
                    $data['visit_points'] = $point->points;
                    $visit = $this->db->order_by('id desc')->limit(10)->where_in('type', array(7, 8))->get_where('point_view', array('userid' => $this->user->userid))->result();
                    $data['visit'] = $visit;
                case 8:
                    $data['regist_points'] = $point->points;
                    break;
            }
        }

        $drafts = $this->db->order_by('id desc')->limit(5)->get_where('glod_reward_view', array('userid' => $this->user->userid, 'type' => 21))->result();
        foreach ($drafts as $draft) {
            $draft->docs = $this->db->select('docid,title,exten')->get_where('doc', array('draftid' => $draft->linkid, 'state' => 1, 'isdel' => 0))->result();
        }
        $data['drafts'] = $drafts;

        $reward = $this->db->order_by('reid desc')->limit(16)->get_where('reward_view', array('state' => 1))->result();
        $data['reward'] = $reward;

        $data['title'] = '我的任务 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的任务 - 我的后台';
        $data['description'] = '我的任务 - 我的后台';

        $this->load->view($this->template . 'center/task', $data);
    }

    public function message()
    {
        if (IS_GET) {
            $data['title'] = '我的消息 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的消息 - 我的后台';
            $data['description'] = '我的消息 - 我的后台';

            $this->load->view($this->template . 'center/message', $data);
        } else {

            $ids_result = $this->db->select('max(id) as id')->group_by('from,to')->where('from <>', $this->user->userid)->get_where('message', ['whos' => $this->user->userid])->result();
            $ids = [];
            foreach ($ids_result as $id) {
                $ids[] = $id->id;
            }

            $cpage = $this->input->post('pagecurrent');
            $pagesize = $this->input->post('pagesize');

            $this->db->where(array('whos' => $this->user->userid))->where_in('id', $ids)->order_by('id desc');

            $total = $this->db->count_all_results('message_view', false);

            if ($pagesize && $cpage) {
                $this->db->limit($pagesize, $pagesize * $cpage - $pagesize);
            }

            $docs = $this->db->get()->result();
            foreach ($docs as $doc) {
                $doc->insertdate = date('Y-m-d', strtotime($doc->insertdate));
            }
            echo json_encode(array('total' => $total, 'data' => $docs));
        }
    }

    public function order()
    {
        $data['title'] = '我的订单 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '我的订单 - 我的后台';
        $data['description'] = '我的订单 - 我的后台';

        $this->load->view($this->template . 'center/order', $data);
    }

    public function order_vip()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid));
        $total = $this->db->count_all_results('viporder_view', false);

        $order = $this->db->order_by('insertdate desc')->limit($pagesize, $pagesize * $cpage - $pagesize)->get()->result();

        foreach ($order as $item) {
            $item->insertdate = date('Y-m-d', strtotime($item->insertdate));
            switch ($item->from) {
                case 1:
                    $item->from = '<span class="tip-bg bg-green">微信</span>';
                    break;
                case 2:
                    $item->from = '<span class="tip-bg bg-blue">支付宝</span>';
                    break;
                default:
                    $item->from = '<span class="tip-bg bg-yellow">其他</span>';
                    break;
            }
            switch ($item->state) {
                case 0:
                    $item->state = '<span style="color:#196">未付款</span>';
                    break;
                case 1:
                    $item->state = '<span style="color:#f60">已付款</span>';
                    break;
                case 2:
                    $item->state = '<span style="color:#f60">完成</span>';
                    break;
                default:
                    $item->state = '';
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $order));
    }

    public function order_glod()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid));
        $total = $this->db->count_all_results('glodorder', false);

        $order = $this->db->order_by('insertdate desc')->limit($pagesize, $pagesize * $cpage - $pagesize)->get()->result();

        foreach ($order as $item) {
            $item->insertdate = date('Y-m-d', strtotime($item->insertdate));
            switch ($item->from) {
                case 1:
                    $item->from = '<span class="tip-bg bg-green">微信</span>';
                    break;
                case 2:
                    $item->from = '<span class="tip-bg bg-blue">支付宝</span>';
                    break;
                default:
                    $item->from = '<span class="tip-bg bg-yellow">其他</span>';
                    break;
            }
            switch ($item->state) {
                case 0:
                    $item->state = '<span style="color:#196">未付款</span>';
                    break;
                case 1:
                    $item->state = '<span style="color:#f60">已付款</span>';
                    break;
                case 2:
                    $item->state = '<span style="color:#f60">完成</span>';
                    break;
                default:
                    $item->state = '';
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $order));
    }

    public function order_cash()
    {
        $cpage = $this->input->post('pagecurrent');
        $pagesize = $this->input->post('pagesize');

        $this->db->where(array('userid' => $this->user->userid));
        $total = $this->db->count_all_results('cashorder', false);

        $order = $this->db->order_by('insertdate desc')->limit($pagesize, $pagesize * $cpage - $pagesize)->get()->result();

        foreach ($order as $item) {
            $item->insertdate = date('Y-m-d', strtotime($item->insertdate));
            $item->tradedate = date('Y-m-d', strtotime($item->tradedate));
            switch ($item->from) {
                case 1:
                    $item->from = '<span class="tip-bg bg-blue">支付宝</span>';
                    break;
                case 2:
                    $item->from = '<span class="tip-bg bg-green">微信</span>';
                    break;
                default:
                    $item->from = '<span class="tip-bg bg-yellow">其他</span>';
                    break;
            }

            switch ($item->tradestate) {
                case 0:
                    $item->tradeno = '';
                    $item->tradedate = '';
                    $item->tradedesc = '';
                    $item->tradestate = '<span style="color:#f60">未打款</span>';
                    break;
                case 1:
                    $item->tradestate = '<span style="color:#129A5C">已付款</span>';
                    break;
            }
            switch ($item->state) {
                case 0:
                    $item->state = '<span style="color:#196">待审核</span>';
                    break;
                case 1:
                    $item->state = '<span style="color:#f60">审核通过</span>';
                    break;
                case -1:
                    $item->state = '<span style="color:#f00">审核未过</span>';
                    break;
            }
        }
        echo json_encode(array('total' => $total, 'data' => $order));
    }

    public function vip()
    {
        $vipgroup = $this->db->order_by('sort')->get_where('vgroup', array('state' => 1))->result();
        $suggest = $this->db->order_by('sort')->get_where('vgroup', array('state' => 1, 'suggest' => 1))->row();
        $payset = $this->db->get('payset')->row();
        $isewm = $this->db->select('isewm')->get('alipayset')->row();

        $data['vipgroup'] = $vipgroup;
        $data['suggest'] = $suggest;
        $data['payset'] = $payset;
        $data['isewm'] = $isewm->isewm;

        $data['title'] = 'VIP充值 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = 'VIP充值 - 我的后台';
        $data['description'] = 'VIP充值 - 我的后台';

        $this->load->view($this->template . 'center/vip', $data);
    }

    public function vippayfinish($orderid)
    {
        if ($orderid && $order = $this->db->get_where('viporder', array('orderid' => $orderid))->row()) {

            if ($user = $this->db->select('userid,groupid')->get_where('user', array('iinvicode' => $this->user->finvicode))->row()) {
                if ($group = $this->db->select('groupid,invite,invitedays')->get_where('group', array('groupid' => $user->groupid))->row()) {
                    if (strpos($group->invite, '%') > 0 && ($group->invitedays == 0 || time() - strtotime($this->user->insertdate) < $group->invitedays * 86400)) {

                        $glodpotdata = array(
                            'userid' => $user->userid,
                            'linkid' => $this->user->userid,
                            'type' => 12,
                            'glods' => $group->invite * $order->cash / 100,
                            'invite' => $group->invite,
                        );
                        $this->db->insert('glodpot', $glodpotdata);

                        $this->db->set('glods', 'glods+' . $group->invite * $order->cash / 100, false)->where('userid',$user->userid)->update('user');
                    }
                }
            }

            $data['order'] = $order;

            $data['title'] = '已开通VIP - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '已开通VIP - 我的后台';
            $data['description'] = '已开通VIP - 我的后台';

            $this->load->view($this->template . 'center/vippayfinish', $data);
        }
    }

    public function glodpay()
    {
        $payset = $this->db->get('payset')->row();
        $isewm = $this->db->select('isewm')->get('alipayset')->row();

        $data['payset'] = $payset;
        $data['isewm'] = $isewm->isewm;

        $data['title'] = '充值 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '充值 - 我的后台';
        $data['description'] = '充值 - 我的后台';

        $this->load->view($this->template . 'center/glodpay', $data);
    }

    public function glodpayfinish($orderid)
    {
        if ($orderid && $order = $this->db->get_where('glodorder', array('orderid' => $orderid))->row()) {
            $data['order'] = $order;

            $data['title'] = '充值完成 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '充值完成 - 我的后台';
            $data['description'] = '充值完成 - 我的后台';

            $this->load->view($this->template . 'center/glodpayfinish', $data);
        }
    }

    public function cash()
    {
        $data['title'] = '提现 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '提现 - 我的后台';
        $data['description'] = '提现 - 我的后台';

        if (!$this->has_right(2)) {
            $data['message'] = '提示：您没有提现权限！';
            $this->load->view($this->template . 'center/cash', $data);
        } else if ($this->user->glods * $this->tradeset->glodrate < $this->tradeset->glodout) {
            $data['message'] = '提示：您的提现金额需要 >= ' . $this->tradeset->glodout . $this->tradeset->glodunit;
            $this->load->view($this->template . 'center/cash', $data);
        } else if ($this->docset->isauth2 && !$this->user->isauth) {
            $data['message'] = '只有认证用户才能提现！';
            $this->load->view($this->template . 'center/cash', $data);
        } else if ($this->db->select('orderid')->get_where('cashorder', ['userid' => $this->user->userid, 'state' => 0])->row()) {
            $data['message'] = '你还有待审核的提现订单，审核后才能再次体现！<a style="color:#19e"  href="center/order.html">查看订单</a>';
            $this->load->view($this->template . 'center/cash', $data);
        } else {
            $this->load->view($this->template . 'center/cash', $data);
        }
    }

    public function cashout()
    {
        $data['title'] = '现金提现 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '现金提现 - 我的后台';
        $data['description'] = '现金提现 - 我的后台';

        if (!$this->has_right(2)) {
            $data['message'] = '提示：您没有提现权限！';
            $this->load->view($this->template . 'center/cash', $data);
            return;
        } else if ($this->user->glods * $this->tradeset->glodrate < $this->tradeset->glodout) {
            $data['message'] = '提示：您的提现金额需要 >= ' . $this->tradeset->glodout . $this->tradeset->glodunit;
            $this->load->view($this->template . 'center/cash', $data);
            return;
        } else if ($this->docset->isauth2 && !$this->user->isauth) {
            $data['message'] = '只有认证用户才能提现！';
            $this->load->view($this->template . 'center/cash', $data);
        } else if ($this->db->select('orderid')->get_where('cashorder', ['userid' => $this->user->userid, 'state' => 0])->row()) {
            $data['message'] = '你还有待审核的提现订单，审核后才能再次体现！<a style="color:#19e"  href="center/order.html">查看订单</a>';
            $this->load->view($this->template . 'center/cash', $data);
            return;
        }

        $glods = $this->input->post('glods'); //交易币
        $from = $this->input->post('from');
        $account = $this->input->post('account');

        if ($glods * $this->tradeset->glodrate >= $this->tradeset->glodout && $glods <= $this->user->glods) {
            $orderdata = array(
                'title' => '提现',
                'userid' => $this->user->userid,
                'glods' => $glods,
                'cash' => number_format($glods * $this->tradeset->glodrate, 2, '.', ''),
                'tradecash' => number_format($glods * $this->tradeset->glodrate * $this->ugroup->divide, 2, '.', ''),
                'from' => $from,
                'account' => $account,
            );
            $this->db->insert('cashorder', $orderdata);
            $this->load->view($this->template . 'center/order', $data);
        } else {
            $data['message'] = '您最多提现' . $this->user->glods * $this->tradeset->glodrate . '元';
            $this->load->view($this->template . 'center/cash', $data);
        }
    }

    public function change()
    {
        $data['title'] = '积分兑换 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '积分兑换 - 我的后台';
        $data['description'] = '积分兑换 - 我的后台';

        if (!$this->has_right(81)) {
            $data['message'] = '提示：您没有积分兑换权限！';
            $this->load->view($this->template . 'center/change', $data);
        } else if ($this->user->points < $this->tradeset->pointout) {
            $data['message'] = '提示：您的积分需要 >= ' . $this->tradeset->pointout . '才能进行兑换';
            $this->load->view($this->template . 'center/change', $data);
        } else {
            $this->load->view($this->template . 'center/change', $data);
        }
    }

    public function changeout()
    {
        $this->right_print(81);

        $data['title'] = '积分兑换 - 我的后台 - ' . $this->site->name;
        $data['keywords'] = '积分兑换 - 我的后台';
        $data['description'] = '积分兑换 - 我的后台';

        $points = $this->input->post('points');

        if ($points >= $this->tradeset->pointout && $points <= $this->user->points) {

            $glods = number_format($points * $this->tradeset->pointrate, 2, '.', '');

            $this->db->set('glods', 'glods+' . $glods, false)->where('userid', $this->user->userid)->update('user');
            $this->db->set('points', 'points-' . $points, false)->where('userid', $this->user->userid)->update('user');

            header('Location: /center.html');

        } else {
            $data['message'] = '您最多兑换' . $this->user->points . '积分';
            $this->load->view($this->template . 'center/cash', $data);
        }
    }

    public function auth($person = null)
    {
        if (IS_GET) {
            $data['user'] = $this->user;

            $data['title'] = '我的认证 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的认证 - 我的后台';
            $data['description'] = '我的认证 - 我的后台';

            if ($row = $this->db->get_where('auth', array('userid' => $this->user->userid))->row()) {
                $data['auth'] = $row;
            } else {
                $data['auth'] = (object) array(
                    'userid' => '0',
                    'comname' => '',
                    'comaddress' => '',
                    'comcode' => '',
                    'realname' => '',
                    'cardid' => '',
                    'phone' => '',
                    'email' => '',
                    'note' => '',
                    'model' => '0',
                    'state' => '0',
                    'authpic1' => 'data/img/nopic.png',
                    'authpic2' => 'data/img/nopic.png',
                    'authpic3' => 'data/img/nopic.png',
                    'authpic4' => 'data/img/nopic.png',
                    'authpic5' => 'data/img/nopic.png',
                    'authpic6' => 'data/img/nopic.png',
                    'authpic7' => 'data/img/nopic.png',
                );
            }
            $this->load->view($this->template . 'center/auth', $data);
        } else {
            $data = array(
                'userid' => $this->user->userid,
                'comname' => $this->input->post('comname'),
                'comaddress' => $this->input->post('comaddress'),
                'comcode' => $this->input->post('comcode'),
                'realname' => $this->input->post('realname'),
                'cardid' => $this->input->post('cardid'),
                'phone' => $this->input->post('phone'),
                'email' => $this->input->post('email'),
                'note' => $this->input->post('note'),
                'authpic1' => $this->input->post('authpic1'),
                'authpic2' => $this->input->post('authpic2'),
                'authpic3' => $this->input->post('authpic3'),
                'authpic4' => $this->input->post('authpic4'),
                'authpic5' => $this->input->post('authpic5'),
                'authpic6' => $this->input->post('authpic6'),
                'authpic7' => $this->input->post('authpic7'),
                'model' => $person == 'person' ? 0 : 1,
                'state' => '0',
            );
            if ($person) {

                if ($this->db->get_where('auth', array('userid' => $this->user->userid))->row()) {
                    echo $this->db->update('auth', $data, array('userid' => $this->user->userid));
                } else {
                    echo $this->db->insert('auth', $data);
                }
            }
        }
    }

    public function authpic($id)
    {
        header('Content-type: image/png');
        readfile('data/img/nopic.png');
    }

    public function group()
    {
        if (IS_GET) {
            $data['user'] = $this->user;

            $data['title'] = '我的用户组 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的用户组 - 我的后台';
            $data['description'] = '我的用户组 - 我的后台';

            $data['groups'] = $this->db->order_by('sort')->get('group')->result();
            $data['vgroups'] = $this->db->order_by('sort')->get('vgroup')->result();

            $data['doc_count'] = $this->db->select('count(*) as count')->get_where('doc', array('userid' => $this->user->userid, 'state' => 1, 'isdel' => 0))->row()->count;
            if ($this->user->userid > 1) {
                $data['togroup'] = $this->db->order_by('docnum', 'desc')->get_where('group', array('docnum <=' => $data['doc_count'], 'groupid >' => 1, 'docnum >' => $this->ugroup->docnum))->row();
            } else {
                $data['togroup'] = null;
            }

            $this->load->view($this->template . 'center/group', $data);
        } else {

        }
    }

    public function ugroup()
    {
        if (IS_GET) {
            $data['user'] = $this->user;

            $data['title'] = '升级用户组 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '升级用户组 - 我的后台';
            $data['description'] = '升级用户组 - 我的后台';

            $doc_count = $this->db->select('count(*) as count')->get_where('doc', array('userid' => $this->user->userid, 'state' => 1, 'isdel' => 0))->row()->count;
            if ($this->user->userid > 1) {
                $togroup = $this->db->order_by('docnum', 'desc')->get_where('group', array('docnum <=' => $doc_count, 'groupid >' => 1, 'docnum >' => $this->ugroup->docnum))->row();
            } else {
                $togroup = null;
            }
            if ($togroup && $togroup->isauth && $this->user->isauth) {
                $this->db->set('groupid', $togroup->groupid, false)->where('userid', $this->user->userid)->update('user');
                $data['msg'] = '恭喜您，已升级为' . $togroup->groupname;
            } else if ($togroup && $togroup->isauth && !$this->user->isauth) {
                $data['msg'] = '需要认证后,才能升级到【' . $togroup->groupname . '】，<a style="color:#fb4a00" href="center/auth.html"> 去认证 </a>。';
            } else if ($togroup) {
                $this->db->set('groupid', $togroup->groupid, false)->where('userid', $this->user->userid)->update('user');
                $data['msg'] = '恭喜您，已升级为' . $togroup->groupname;
            } else {
                $data['msg'] = '您文档数量不够，暂时不能升级';
            }
            $this->load->view($this->template . 'center/ugroup', $data);
        } else {

        }
    }

    public function account()
    {
        if (IS_GET) {
            $data['user'] = $this->user;

            $data['title'] = '我的账号 - 我的后台 - ' . $this->site->name;
            $data['keywords'] = '我的账号 - 我的后台';
            $data['description'] = '我的账号 - 我的后台';

            $this->load->view($this->template . 'center/account', $data);
        } else {
            $data = array(
                'nickname' => $this->input->post('nickname'),
                'phone' => $this->input->post('phone'),
                'sex' => $this->input->post('sex'),
                'address' => $this->input->post('address'),
            );

            pointpot(3, $this->user->userid, '0');
            echo $this->db->update('user', $data, array('userid' => $this->user->userid));
        }
    }

    public function photo()
    {
        $cover = 'data/photo/' . $this->user->userid . '.pic';
        if ($_FILES && !$_FILES['file']['error']) {
            $size = $_FILES["file"]['size'];
            $exten = get_exten($_FILES["file"]['name']);
            if ($size <= 1024 * 1024) {
                if ($exten === "png" || $exten === "jpeg" || $exten === "jpg" || $exten === "gif" || $exten === "bmp") {
                    if (move_uploaded_file($_FILES['file']['tmp_name'], $cover)) {
                        $this->db->set('photo', $exten)->where('userid', $this->user->userid)->update('ds_user');
                        echo 1;
                    } else {
                        echo -1;
                    }
                } else {
                    die('{"code": 101, "message": "扩展名不对"}');
                }
            } else {
                die('{"code": 102, "message": "太大了"}');
            }
        } else {
            die('{"code": 104, "message": "No File"}');
        }
    }

}
