<?php

defined('BASEPATH') or exit('No direct script access allowed');

class Article extends Admin_Controller
{

    public function __construct()
    {
        parent::__construct();
        $menu = array(
            'title' => '文章管理',
            'menu' => array(
                'admin/article/audit' => '待审文章',
                'admin/article/online' => '在线文章',
                'admin/article/recycle' => '回收站',
                'javascript:;" class="i' => '<span></span>',
                'admin/article/comment/audit' => '待审评论',
                'admin/article/comment/online' => '已审评论',
                'javascript:;;" class="i' => '<span></span>',
                'admin/article/tag' => '文章分类',
            ));
        $this->load->vars('menu', $menu);
    }

    public function index($which)
    {
        if (IS_GET) {
            $this->load->view($this->template . 'admin/article/index');
        } elseif (IS_POST) {
            $this->articlelist($which);
        }
    }

    public function articlelist($which)
    {
        $searchcol = $this->input->post('searchcol');
        $searchtext = $this->input->post('searchtext');
        $sortcol = $this->input->post('sortcol');
        $sorttext = $this->input->post('sorttext');
        $pagesize = $this->input->post('pagesize');
        $pagecurrent = $this->input->post('pagecurrent');

        switch ($which) {
            case 'audit':
                $this->db->where(array('state' => 0));
                break;
            case 'online':
                $this->db->where(array('state' => 1));
                break;
            case 'recycle':
                $this->db->where(array('state' => -1));
                break;
        }
        if ($searchtext != '') {
            $this->db->like($searchcol, $searchtext);
        }

        $total = $this->db->count_all_results('article_view', false);

        $articles = $this->db->order_by($sortcol, $sorttext)->limit($pagesize, ($pagesize * $pagecurrent - $pagesize))->get()->result();
        foreach ($articles as $article) {
            $article->tagname = $article->tagname ? $article->tagname : '<span style="color:#f00">无标签</span>';
            $article->istop = $article->istop ? '<span class="tip-bg bg-blue">置顶</span>' : '';
            $article->commentnum = $this->db->select('count(*) as count')->get_where('article_comment', array('state' => 1, 'articleid' => $article->articleid))->row()->count;
            $article->insertdate = date('Y-m-d', strtotime($article->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $articles));
    }

    public function article_edit($articleid)
    {
        if (IS_GET) {
            if ($articleid && $row = $this->db->get_where('article', array('articleid' => $articleid))->row()) {
                $data['article'] = $row;
            } else {
                $data['article'] = (object) array(
                    'articleid' => 0,
                    'tagid' => 0,
                    'title' => '',
                    'word' => '',
                );
            }
            $data['tag'] = $this->db->order_by('sort')->get_where('article_tag', ['state' => 1])->result();
            $this->load->view($this->template . 'admin/article/article_edit', $data);
        } elseif (IS_POST) {
            $data = array(
                'tagid' => $this->input->post('tagid'),
                'title' => $this->input->post('title'),
                'word' => $this->input->post('word'),
                'state' => 1,
            );
            if ($articleid) {
                echo $this->db->update('article', $data, array('articleid' => $articleid));
            } else {
                echo $this->db->insert('article', $data);
            }
        }
    }

    public function article_audit($articleids = 0)
    {
        if (IS_GET) {
            $data['articleids'] = $articleids;
            $this->load->view($this->template . 'admin/article/article_audit', $data);
        } elseif (IS_POST) {
            if ($articleids) {
                $passed = $this->input->post('passed');
                $nopass = $this->input->post('nopass');
                $note = $this->input->post('note');

                $data['state'] = 0;
                if ($passed == '1') {
                    $data['state'] = 1;
                }
                if ($nopass == '1') {
                    $data['state'] = -1;
                }
                $data['note'] = $note;
                foreach (explode('_', $articleids) as $articleid) {
                    echo $this->db->update('article', $data, array('articleid' => $articleid));
                }
            }
        }
    }

    public function article_imp($articleids = 0)
    {
        if (IS_GET) {
            $data['articleids'] = $articleids;
            $this->load->view($this->template . 'admin/article/article_imp', $data);
        } elseif (IS_POST) {
            if ($articleids) {
                $istop = $this->input->post('istop');
                $note = $this->input->post('note');

                $data['istop'] = $istop;
                $data['note'] = $note;
                foreach (explode('_', $articleids) as $articleid) {
                    echo $this->db->update('article', $data, array('articleid' => $articleid));
                }
            }
        }
    }

    public function article_del($articleids = 0)
    {
        if (IS_GET) {
            $data['articleids'] = $articleids;
            $this->load->view($this->template . 'admin/article/article_del', $data);
        } elseif (IS_POST) {
            if ($articleids) {
                $isdel = $this->input->post('isdel');
                $note = $this->input->post('note');

                if ($isdel) {
                    $data['state'] = -1;
                } else {
                    $data['state'] = 0;
                }
                $data['note'] = $note;
                foreach (explode('_', $articleids) as $articleid) {
                    echo $this->db->update('article', $data, array('articleid' => $articleid));
                }
            }
        }
    }

    public function article_del2($articleids = 0)
    {
        if ($articleids) {
            foreach (explode('_', $articleids) as $articleid) {
                $this->db->delete('article', array('articleid' => $articleid));
                $this->db->delete('article_comment', array('articleid' => $articleid));
            }
        }
    }

    public function comment($which)
    {
        if (IS_GET) {
            $this->load->view($this->template . 'admin/article/comment');
        } elseif (IS_POST) {
            $this->commentlist($which);
        }
    }

    public function commentlist($which)
    {
        $searchcol = $this->input->post('searchcol');
        $searchtext = $this->input->post('searchtext');
        $sortcol = $this->input->post('sortcol');
        $sorttext = $this->input->post('sorttext');
        $pagesize = $this->input->post('pagesize');
        $pagecurrent = $this->input->post('pagecurrent');

        switch ($which) {
            case 'audit':
                $this->db->where(array('state' => 0));
                break;
            case 'online':
                $this->db->where(array('state' => 1));
                break;
        }
        if ($searchtext != '') {
            $this->db->like($searchcol, $searchtext);
        }

        $total = $this->db->count_all_results('article_comment_view', false);

        $comments = $this->db->order_by($sortcol, $sorttext)->limit($pagesize, ($pagesize * $pagecurrent - $pagesize))->get()->result();
        foreach ($comments as $comment) {
        }
        echo json_encode(array('total' => $total, 'data' => $comments));
    }

    public function comment_audit($commentids = 0)
    {
        if (IS_GET) {
            $data['commentids'] = $commentids;
            $this->load->view($this->template . 'admin/article/comment_audit', $data);
        } elseif (IS_POST) {
            if ($commentids) {
                $passed = $this->input->post('passed');
                $nopass = $this->input->post('nopass');
                $note = $this->input->post('note');

                $data['state'] = 0;
                if ($passed == '1') {
                    $data['state'] = 1;
                    $data['note'] = $note;
                    foreach (explode('_', $commentids) as $commentid) {
                        echo $this->db->update('article_comment', $data, array('commentid' => $commentid));
                    }
                }
                if ($nopass == '1') {
                    $this->comment_del2($commentids);
                }
            }
        }
    }

    public function comment_del2($commentids = 0)
    {
        if ($commentids) {
            foreach (explode('_', $commentids) as $commentid) {
                $this->db->delete('article_comment', array('commentid' => $commentid));
            }
        }
    }

    public function tag()
    {
        $data['tag'] = $this->db->order_by('sort')->get('article_tag')->result();
        $this->load->view($this->template . 'admin/article/tag', $data);
    }

    public function tag_edit($tagid)
    {
        if (IS_GET) {
            if ($tagid && $row = $this->db->get_where('article_tag', array('tagid' => $tagid))->row()) {
                $data['tag'] = $row;
            } else {
                $data['tag'] = (object) array(
                    'tagid' => '0',
                    'tagname' => '',
                    'seotitle' => '',
                    'sort' => '',
                    'state' => '1',
                );
            }
            $this->load->view($this->template . 'admin/article/tag_edit', $data);
        } elseif (IS_POST) {
            $data = array(
                'tagname' => $this->input->post('tagname'),
                'seotitle' => $this->input->post('seotitle'),
                'sort' => $this->input->post('sort'),
                'state' => $this->input->post('state'),
            );
            if ($tagid) {
                echo $this->db->update('article_tag', $data, array('tagid' => $tagid));
            } else {
                echo $this->db->insert('article_tag', $data);
            }
        }
    }

    public function tag_del($tagid)
    {
        if ($tagid) {
            echo $this->db->delete('article_tag', array('tagid' => $tagid));
        }
    }

    public function tag_state()
    {
        $data = array(
            'state' => $this->input->post('val'),
        );
        if ($tagid = $this->input->post('key')) {
            echo $this->db->update('article_tag', $data, array('tagid' => $tagid));
        }
    }

}
