<?php

defined('BASEPATH') or exit('No direct script access allowed');

class Ask extends Admin_Controller
{

    public function __construct()
    {
        parent::__construct();
        $menu = array(
            'title' => '问答管理',
            'menu' => array(
                'admin/ask/audit' => '待审问题',
                'admin/ask/online' => '在线问题',
                'admin/ask/recycle' => '回收站',
                'javascript:;" class="i' => '<span></span>',
                'admin/ask/comment/audit' => '待审回答',
                'admin/ask/comment/online' => '已审回答',
                'javascript:;;" class="i' => '<span></span>',
                'admin/ask/tag' => '问答版块',
            ));
        $this->load->vars('menu', $menu);
    }

    public function index($which)
    {
        if (IS_GET) {
            $this->load->view($this->template . 'admin/ask/index');
        } elseif (IS_POST) {
            $this->asklist($which);
        }
    }

    public function asklist($which)
    {
        $searchcol = $this->input->post('searchcol');
        $searchtext = $this->input->post('searchtext');
        $sortcol = $this->input->post('sortcol');
        $sorttext = $this->input->post('sorttext');
        $pagesize = $this->input->post('pagesize');
        $pagecurrent = $this->input->post('pagecurrent');

        switch ($which) {
            case 'audit':
                $this->db->where(array('state' => 0));
                break;
            case 'online':
                $this->db->where(array('state' => 1));
                break;
            case 'recycle':
                $this->db->where(array('state' => -1));
                break;
        }
        if ($searchtext != '') {
            $this->db->like($searchcol, $searchtext);
        }

        $total = $this->db->count_all_results('ask_view', false);

        $asks = $this->db->order_by($sortcol, $sorttext)->limit($pagesize, ($pagesize * $pagecurrent - $pagesize))->get()->result();
        foreach ($asks as $ask) {
            $ask->tagname = $ask->tagname ? $ask->tagname : '<span style="color:#f00">无分类</span>';
            $ask->istop = $ask->istop ? '<span class="tip-bg bg-blue">置顶</span>' : '';
            $ask->commentnum = $this->db->select('count(*) as count')->get_where('ask_comment', array('state' => 1, 'askid' => $ask->askid))->row()->count;
            $ask->insertdate = date('Y-m-d', strtotime($ask->insertdate));
        }
        echo json_encode(array('total' => $total, 'data' => $asks));
    }

    public function ask_edit($askid)
    {
        if (IS_GET) {
            if ($askid && $row = $this->db->get_where('ask', array('askid' => $askid))->row()) {
                $data['ask'] = $row;
            } else {
                $data['ask'] = (object) array(
                    'askid' => 0,
                    'tagid' => 0,
                    'title' => '',
                    'word' => '',
                );
            }
            $data['tag'] = $this->db->order_by('sort')->get_where('ask_tag', ['state' => 1])->result();
            $this->load->view($this->template . 'admin/ask/ask_edit', $data);
        } elseif (IS_POST) {
            $data = array(
                'tagid' => $this->input->post('tagid'),
                'title' => $this->input->post('title'),
                'word' => $this->input->post('word'),
                'state' => 1,
            );
            if ($askid) {
                echo $this->db->update('ask', $data, array('askid' => $askid));
            } else {
                echo $this->db->insert('ask', $data);
            }
        }
    }

    public function ask_audit($askids = 0)
    {
        if (IS_GET) {
            $data['askids'] = $askids;
            $this->load->view($this->template . 'admin/ask/ask_audit', $data);
        } elseif (IS_POST) {
            if ($askids) {
                $passed = $this->input->post('passed');
                $nopass = $this->input->post('nopass');
                $note = $this->input->post('note');

                $data['state'] = 0;
                if ($passed == '1') {
                    $data['state'] = 1;
                }
                if ($nopass == '1') {
                    $data['state'] = -1;
                }
                $data['note'] = $note;
                foreach (explode('_', $askids) as $askid) {
                    echo $this->db->update('ask', $data, array('askid' => $askid));
                }
            }
        }
    }

    public function ask_imp($askids = 0)
    {
        if (IS_GET) {
            $data['askids'] = $askids;
            $this->load->view($this->template . 'admin/ask/ask_imp', $data);
        } elseif (IS_POST) {
            if ($askids) {
                $istop = $this->input->post('istop');
                $note = $this->input->post('note');

                $data['istop'] = $istop;
                $data['note'] = $note;
                foreach (explode('_', $askids) as $askid) {
                    echo $this->db->update('ask', $data, array('askid' => $askid));
                }
            }
        }
    }

    public function ask_del($askids = 0)
    {
        if (IS_GET) {
            $data['askids'] = $askids;
            $this->load->view($this->template . 'admin/ask/ask_del', $data);
        } elseif (IS_POST) {
            if ($askids) {
                $isdel = $this->input->post('isdel');
                $note = $this->input->post('note');

                if ($isdel) {
                    $data['state'] = -1;
                } else {
                    $data['state'] = 0;
                }
                $data['note'] = $note;
                foreach (explode('_', $askids) as $askid) {
                    echo $this->db->update('ask', $data, array('askid' => $askid));
                }
            }
        }
    }

    public function ask_del2($askids = 0)
    {
        if ($askids) {
            foreach (explode('_', $askids) as $askid) {
                $this->db->delete('ask', array('askid' => $askid));
                $this->db->delete('ask_comment', array('askid' => $askid));
            }
        }
    }

    public function comment($which)
    {
        if (IS_GET) {
            $this->load->view($this->template . 'admin/ask/comment');
        } elseif (IS_POST) {
            $this->commentlist($which);
        }
    }

    public function commentlist($which)
    {
        $searchcol = $this->input->post('searchcol');
        $searchtext = $this->input->post('searchtext');
        $sortcol = $this->input->post('sortcol');
        $sorttext = $this->input->post('sorttext');
        $pagesize = $this->input->post('pagesize');
        $pagecurrent = $this->input->post('pagecurrent');

        switch ($which) {
            case 'audit':
                $this->db->where(array('state' => 0));
                break;
            case 'online':
                $this->db->where(array('state' => 1));
                break;
        }
        if ($searchtext != '') {
            $this->db->like($searchcol, $searchtext);
        }

        $total = $this->db->count_all_results('ask_comment_view', false);

        $comments = $this->db->order_by($sortcol, $sorttext)->limit($pagesize, ($pagesize * $pagecurrent - $pagesize))->get()->result();
        foreach ($comments as $comment) {
        }
        echo json_encode(array('total' => $total, 'data' => $comments));
    }

    public function comment_audit($commentids = 0)
    {
        if (IS_GET) {
            $data['commentids'] = $commentids;
            $this->load->view($this->template . 'admin/ask/comment_audit', $data);
        } elseif (IS_POST) {
            if ($commentids) {
                $passed = $this->input->post('passed');
                $nopass = $this->input->post('nopass');
                $note = $this->input->post('note');

                $data['state'] = 0;
                if ($passed == '1') {
                    $data['state'] = 1;
                    $data['note'] = $note;
                    foreach (explode('_', $commentids) as $commentid) {
                        echo $this->db->update('ask_comment', $data, array('commentid' => $commentid));
                    }
                }
                if ($nopass == '1') {
                    $this->comment_del2($commentids);
                }
            }
        }
    }

    public function comment_del2($commentids = 0)
    {
        if ($commentids) {
            foreach (explode('_', $commentids) as $commentid) {
                $this->db->delete('ask_comment', array('commentid' => $commentid));
            }
        }
    }

    public function tag()
    {
        $data['tag'] = $this->db->order_by('sort')->get('ask_tag')->result();
        $this->load->view($this->template . 'admin/ask/tag', $data);
    }

    public function tag_edit($tagid)
    {
        if (IS_GET) {
            if ($tagid && $row = $this->db->get_where('ask_tag', array('tagid' => $tagid))->row()) {
                $data['tag'] = $row;
            } else {
                $data['tag'] = (object) array(
                    'tagid' => '0',
                    'tagname' => '',
                    'seotitle' => '',
                    'sort' => '',
                    'state' => '1',
                );
            }
            $this->load->view($this->template . 'admin/ask/tag_edit', $data);
        } elseif (IS_POST) {
            $data = array(
                'tagname' => $this->input->post('tagname'),
                'seotitle' => $this->input->post('seotitle'),
                'sort' => $this->input->post('sort'),
                'state' => $this->input->post('state'),
            );
            if ($tagid) {
                echo $this->db->update('ask_tag', $data, array('tagid' => $tagid));
            } else {
                echo $this->db->insert('ask_tag', $data);
            }
        }
    }

    public function tag_del($tagid)
    {
        if ($tagid) {
            echo $this->db->delete('ask_tag', array('tagid' => $tagid));
        }
    }

    public function tag_state()
    {
        $data = array(
            'state' => $this->input->post('val'),
        );
        if ($tagid = $this->input->post('key')) {
            echo $this->db->update('ask_tag', $data, array('tagid' => $tagid));
        }
    }

}
