<?php

defined('BASEPATH') or exit('No direct script access allowed');

class DS_Controller extends CI_Controller
{
    protected $user = null;
    protected $ugroup = null;
    protected $vgroup = null;
    protected $site = null;
    protected $seo = null;
    protected $docset = null;
    protected $loginset = null;
    protected $tradeset = null;
    protected $template = null;
    protected $iswap = null;
    protected $iswx = null;

    public function __construct()
    {
        parent::__construct();

        //$this->output->enable_profiler(TRUE);

        date_default_timezone_set('Asia/Shanghai');

        //url带session，但自己的sessionid不等于带的sessionid，说明第一次访问，删除自己的sessionid，用带的session覆盖自己的，如果相等删除会把账号踢出去
        if (isset($_GET['session_id']) && ($session_id = $_GET['session_id']) && session_id() != $session_id) {
            session_destroy();
            session_id($session_id);
            Session_start();
            header('Location:' . $_SERVER['PHP_SELF']);
        }

        if (isset($_SESSION['userid']) && $_SESSION['userid'] > 0) {
            $this->user = get_user2($_SESSION['userid']);
        } else if (isset($_COOKIE['id']) && isset($_COOKIE['in'])) {
            $this->user = get_user($this->input->cookie('id'), $this->input->cookie('in'));
        }
        if (!$this->user) {
            $this->user = (object) array('userid' => $this->nick_userid(), 'username' => '游客', 'nickname' => '', 'groupid' => 0, 'glods' => 0, 'vgroupid' => 0, 'isauth' => 0);
        }

        $_SESSION['userid'] = $this->user->userid;

        $this->ugroup = $this->db->get_where('group', array('groupid' => $this->user->groupid))->row();
        $this->vgroup = get_vipgroup($this->user->vgroupid); //null 说明没开通vip
        $this->site = $this->db->get('site')->row();
        $this->seo = $this->db->get('seo')->row();
        $this->docset = $this->db->get('docset')->row();
        $this->loginset = $this->db->get('loginset')->row();
        $this->tradeset = get_tradeset();

        if (!$this->user || !$this->ugroup || !$this->site || !$this->docset || !$this->tradeset) {
            echo '系统出现异常';
            exit();
        }

        $ip = getip();
        $hasforbidip = $this->db->get_where('forbidip', array('ip' => $ip, 'state' => 1))->row();
        if ($hasforbidip) {
            echo '禁止访问';
            exit;
        }

        //每天登录
        if ($this->user->groupid && $points = get_points(2)) {
            $has = $this->db->where('TO_DAYS(NOW()) - TO_DAYS(insertdate) =', 0)->get_where('pointpot', array('type' => 2, 'userid' => $this->user->userid));
            if ($has->num_rows() <= 0) {
                $this->db->set('points', 'points+' . $points->points, false)->where('userid', $this->user->userid)->update('user');
                $potdata = array(
                    'type' => 2,
                    'userid' => $this->user->userid,
                    'points' => $points->points,
                    'docid' => 0,
                    'ip' => getip(),
                );
                $this->db->insert('pointpot', $potdata);
            }
        }

        //访问推广
        if ($from = $this->input->get('f')) {
            pointpot(7, $from, '0', getip());
            $_SESSION['from'] = $from;
        }

        if (iswap() && !isset($_GET['nomobile'])) {
            $this->template = 'template/' . $this->site->template . '/wap/';
            $this->iswap = 1;
            $this->iswx = iswx();
        } else {
            $this->template = 'template/' . $this->site->template . '/pc/';
        }
    }

    public function send_email($to, $subject, $body, $attachs = null)
    {
        $this->load->library('email');
        $row = $this->db->get('smtp')->row();
        if ($row) {
            $config['protocol'] = 'smtp';
            $config['smtp_host'] = $row->smtp;
            $config['smtp_port'] = $row->port;
            $config['smtp_user'] = $row->username;
            $config['smtp_pass'] = $row->password;
            $config['mailtype'] = 'html';
            $config['validate'] = true;
            $config['crlf'] = "\r\n"; //PHP_EOL;
            $config['newline'] = "\r\n"; //PHP_EOL;
            $this->email->initialize($config);

            $this->email->from($row->email, $this->site->name);
            $this->email->to($to);
            $this->email->subject($subject);
            $this->email->message($body);

            if ($attachs) {
                foreach ($attachs as $attach) {
                    $this->email->attach($attach);
                }
            }

            if ($this->email->send()) {
                return 1;
            }
        }
        return 0;
    }

    public function has_right($right)
    {
        if ($this->ugroup && in_array($right, explode(',', $this->ugroup->rights))) {
            return true;
        } else {
            return false;
        }
    }

    public function right_print($right, $message = '您没有权限访问这个页面')
    {
        if (!$this->ugroup || !in_array($right, explode(',', $this->ugroup->rights))) {
            if ($this->user->groupid) {
                $data['title'] = '提示 - ' . $this->site->name;
                $data['keywords'] = '提示';
                $data['description'] = '提示';

                $data['message'] = $message;
                echo $this->load->view($this->template . 'tip', $data, true);
                exit;
            } else {
                header('Location: /login.html');
                exit;
            }
        }
    }

    private function nick_userid()
    {
        if (isset($_SESSION['userid'])) {
            return $_SESSION['userid'];
        } else {
            return mt_rand(-99999999, -10000000);
        }
    }
}

class Home_Controller extends DS_Controller
{

    public $type = null;

    public function __construct()
    {
        parent::__construct();
        //$this->output->enable_profiler(TRUE);
        $this->load->vars('user', $this->user);
        $this->load->vars('ugroup', $this->ugroup);
        $this->load->vars('vgroup', $this->vgroup);
        $this->load->vars('site', $this->site);
        $this->load->vars('seo', $this->seo);
        $this->load->vars('docset', $this->docset);
        $this->load->vars('loginset', $this->loginset);
        $this->load->vars('tradeset', $this->tradeset);
        $this->load->vars('template', $this->template);
        $this->load->vars('iswx', $this->iswx);

        $this->load->vars('type_array', get_type_array());
        $this->load->vars('navbar', $this->get_nav());
        $this->load->vars('about', $this->get_about());
        $this->load->vars('hotkey', $this->db->order_by('sort')->get_where('hotkey', array('state' => '1'))->result());

        if (!$this->has_right(1) && $this->router->class != 'login') {
            header('Location: /login.html');
            exit;
        }

        foreach ($_POST as $key => $post) {
            if (!is_array($post) && strpos($post, '<script>') !== false) {
                $_POST[$key] = str_ireplace('<script>', '&lt;script&gt;', $_POST[$key]);
            }
            if (!is_array($post) && strpos($post, '</script>') !== false) {
                $_POST[$key] = str_ireplace('</script>', '&lt;/script&gt;', $_POST[$key]);
            }
            if (!is_array($post) && strpos($post, ';') !== false) {
                $_POST[$key] = str_ireplace(';', '；', $_POST[$key]);
            }
            if (!is_array($post) && strpos($post, "'") !== false) {
                //$_POST[$key] = str_ireplace( "'", '‘', $_POST[$key] );
            }
            if (!is_array($post) && strpos($post, '"') !== false) {
                //$_POST[$key] = str_ireplace( '"', '“', $_POST[$key] );
            }
        }
        foreach ($_GET as $key => $get) {
            if (!is_array($get) && strpos($get, '<script>') !== false) {
                $_GET[$key] = str_ireplace('<script>', '&lt;script&gt;', $_GET[$key]);
            }
            if (!is_array($get) && strpos($get, '</script>') !== false) {
                $_GET[$key] = str_ireplace('</script>', '&lt;/script&gt;', $_GET[$key]);
            }
            if (!is_array($get) && strpos($get, ';') !== false) {
                $_GET[$key] = str_ireplace(';', '；', $_GET[$key]);
            }
            if (!is_array($get) && strpos($get, "'") !== false) {
                //$_GET[$key] = str_ireplace( "'", '‘', $_GET[$key] );
            }
            if (!is_array($get) && strpos($get, '"') !== false) {
                //$_GET[$key] = str_ireplace( '"', '“', $_GET[$key] );
            }
        }

        //过滤词
        $badwords = $this->db->order_by('sort')->get_where('badword', array('state' => '1'))->result();
        foreach ($badwords as $badword) {
            foreach ($_POST as $key => $post) {
                if (!is_array($post) && strpos($post, $badword->word) !== false) {
                    $_POST[$key] = str_ireplace($badword->word, $badword->word2, $_POST[$key]);
                }
            }
            foreach ($_GET as $key => $get) {
                if (!is_array($get) && strpos($get, $badword->word) !== false) {
                    $_GET[$key] = str_ireplace($badword->word, $badword->word2, $_GET[$key]);
                }
            }
        }

        if ($this->loginset->qq) {
            $this->load->vars('qqloginset', $this->db->get('qqloginset')->row());
        }

        if ($this->iswx && get_points(9)) {
            $this->load->library('Gzhshare/Gzhshare');
            $gzhshare = $this->gzhshare->GetSignPackage();
            $this->load->vars('gzhshare', $gzhshare);
        }
    }

    private function get_about()
    {
        $abouts = $this->db->select('id,title,link,groupname')->order_by('groupid,sort')->get_where('about_view', array('state' => 1))->result();
        $about = [];
        foreach ($abouts as $item) {
            $about[$item->groupname][] = $item;
        }
        return $about;
    }

    private function get_nav()
    {
        $navbar = $this->db->order_by('sort')->get('navbar')->result();
        $nav = [];
        foreach ($navbar as $n) {
            $nav[$n->id] = $n;
        }
        return $nav;
    }

}

class Admin_Controller extends DS_Controller
{
    public function __construct()
    {
        parent::__construct();
        //$this->output->enable_profiler(TRUE);
        if (!$this->has_right(4) && !($this->has_right(3) && in_array($this->router->fetch_class(), ['user', 'type', 'doc', 'topic', 'reward', 'article', 'ask']))) {
            header('Location: /login.html');
            exit;
        }

        $this->load->vars('user', $this->user);
        $this->load->vars('ugroup', $this->ugroup);
        $this->load->vars('site', $this->site);
        $this->load->vars('seo', $this->seo);
        $this->load->vars('tradeset', $this->tradeset);
        $this->load->vars('template', $this->template);

        $adminips = $this->db->get_where('adminip', array('state' => 1))->result();
        if ($adminips) {
            $ok = false;
            foreach ($adminips as $adminip) {
                if ($adminip->ip == getip()) {
                    $ok = true;
                }
            }
            if (!$ok) {
                exit("IP地址禁止访问后台");
            }
        }
    }

}
